# Copyright (C) 2022 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
import pydantic


class WarehouseReference(pydantic.BaseModel):
    """A reference to a **Warehouse**."""
    id: int = pydantic.Field(
        default=...,
        title="Warehouse ID",
        description="The warehouse identifier as retained in Picqer. "
    )

    name: str = pydantic.Field(
        default=...,
        title="Name",
        description="The current name of the **Warehouse**."
    )